pub struct SelectionStyle {
pub style: Option<Style>,
pub marker: Option<&'static str>,
pub disabled: bool,
}Expand description
Selection styling for list components
Fields
style: Option<Style>Style applied to selected item (default: Cyan + Bold)
marker: Option<&'static str>Prefix marker for selected item (default: “> “)
disabled: boolSet to true to disable all component selection styling (user handles it entirely in their Line rendering)
Implementations
Sourceimpl SelectionStyle
impl SelectionStyle
Sourcepub fn marker_only(marker: &'static str) -> Self
pub fn marker_only(marker: &'static str) -> Self
Create selection style with only a marker, no style change
Sourcepub fn style_only(style: Style) -> Self
pub fn style_only(style: Style) -> Self
Create selection style with only a style change, no marker