Shared command names understood by built-in interactive components.
These constants are plain &'static str values so they can be used anywhere
command strings are accepted, including keybinding setup and tests.
Modules
- text_
input - Text input command names.
Constants
- CANCEL
- Cancel the current interaction.
- CONFIRM
- Confirm the current item.
- DOWN
- Alias for
NEXTused by directional widgets. - END
- Alias for
LASTused by home/end style keymaps. - FIRST
- Move to the first item or top of content.
- HOME
- Alias for
FIRSTused by home/end style keymaps. - LAST
- Move to the last item or bottom of content.
- LEFT
- Move or collapse left in hierarchical widgets.
- NEXT
- Move to the next item or line.
- PAGE_
DOWN - Move down by one page.
- PAGE_UP
- Move up by one page.
- PREV
- Move to the previous item or line.
- RIGHT
- Move or expand right in hierarchical widgets.
- SELECT
- Select the current item.
- SUBMIT
- Submit the current value.
- TOGGLE
- Toggle the current item.
- UP
- Alias for
PREVused by directional widgets.