Shared styling types for tui-dispatch-components
All component styles follow a standard pattern with these common fields:
border: Option<BorderStyle>- optional border configurationpadding: Padding- inner paddingbg: Option<Color>- background color
Use the ComponentStyle trait to access these in generic code.
Structs
- Base
Style - Shared base styling configuration for all components.
- Border
Style - Border styling configuration
- Borders
- Bitflags that can be composed to set the visible borders essentially on the block widget.
- Modifier
- Modifier changes the way a piece of text is displayed.
- Padding
- Padding configuration for components
- Scrollbar
Style - Scrollbar styling configuration
- Selection
Style - Selection styling for list components
- Style
- Style lets you control the main characteristics of the displayed elements.
Enums
- Color
- ANSI Color
Traits
- Component
Style - Trait for component styles that embed a shared
BaseStyle.
Functions
- highlight_
substring - Highlight substring matches in text (case-insensitive)